@@ -7,8 +7,7 @@ from __future__ import absolute_import
 import unittest
 
 from django.core.management import call_command
-
-from nine.versions import DJANGO_GTE_1_10
+from django.urls import reverse
 
 import pytest
 
@@ -32,11 +31,6 @@ from .base import (
 )
 from .data_mixins import AddressesMixin, BooksMixin
 
-if DJANGO_GTE_1_10:
-    from django.urls import reverse
-else:
-    from django.core.urlresolvers import reverse
-
 __title__ = 'django_elasticsearch_dsl_drf.tests.test_filtering_common'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = '2017-2020 Artur Barseghyan'
