@@ -7,11 +7,10 @@ from __future__ import absolute_import
 import unittest
 
 from django.core.management import call_command
+from django.urls import reverse
 
 from elasticsearch.connection.base import TransportError
 
-from nine.versions import DJANGO_GTE_1_10
-
 import pytest
 
 from rest_framework import status
@@ -21,11 +20,6 @@ import factories
 from ..constants import SEPARATOR_LOOKUP_COMPLEX_VALUE
 from .base import BaseRestFrameworkTestCase
 
-if DJANGO_GTE_1_10:
-    from django.urls import reverse
-else:
-    from django.core.urlresolvers import reverse
-
 __title__ = 'django_elasticsearch_dsl_drf.tests.test_filtering_geo_spatial'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = '2017-2020 Artur Barseghyan'
