@@ -54,10 +54,13 @@ class EmptySearch(object):
 class DictionaryProxy(object):
     """Dictionary proxy."""
 
-    def __init__(self, mapping):
+    def __init__(self, mapping, meta=None):
         self.__mapping = mapping
+        self.meta = meta
 
     def __getattr__(self, item):
+        if item == "meta":
+            return self.meta
         val = self.__mapping.get(item, None)
         if isinstance(val, datetime.datetime) and not val.tzinfo:
             val = val.date()
